@@ -44,23 +44,23 @@ class DetectorHttpConnector:
                                            url_query=payload,
                                            headers=self._construct_headers())
 
-        return dict_to_dataclass(answer["done"], self.detector_settings_type)
+        return dict_to_dataclass(answer["result"], self.detector_settings_type)
 
-    async def set_settings(self, detector_settings: DetectorSettingsType, token: str) -> T:
+    async def set_settings(self, detector_settings: T, token: str) -> T:
         payload = {"token": token}
         payload.update(custom_dumps(detector_settings))
         answer = await self._connector.post_json("/settings/correct",
                                                  payload=payload,
                                                  headers=self._construct_headers())
-        return dict_to_dataclass(answer["done"], self.detector_settings_type)
+        return dict_to_dataclass(answer["result"], self.detector_settings_type)
 
-    async def autotune_settings(self, detection: DetectionAnalyzeResultType, token: str) -> T:
+    async def autotune_settings(self, detection: T, token: str) -> T:
         payload = {"token": token}
         payload.update({"detection": custom_dumps(detection)})
         answer = await self._connector.post_json("/settings/correct",
                                                  payload=payload,
                                                  headers=self._construct_headers())
-        return dict_to_dataclass(answer["done"], self.detector_settings_type)
+        return dict_to_dataclass(answer["result"], self.detector_settings_type)
 
     def _construct_headers(self) -> dict[str, str]:
         return {"server_name": self.context.project_name}
